@@ -2,21 +2,22 @@
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
  * Copyright (C) 2011, 2012, 2014 Loic J. Duros
+ * Copyright (C) 2014, 2015 Nik Nyby
  *
- * This program is free software: you can redistribute it and/or modify
+ * This file is part of GNU LibreJS.
+ *
+ * GNU LibreJS is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * GNU LibreJS is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see  <http://www.gnu.org/licenses/>.
- *
- *
+ * along with GNU LibreJS.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* list generated one time using tools/jslibfetcher.py */
@@ -322,7 +323,8 @@ var list = [
 ];
 
 list = ["http://code.jquery.com/jquery-1.8.2.min.js"];
-const scriptsCached = require("script_entries/scripts_cache").scriptsCached;
+const scriptsCached = require("../lib/script_entries/scripts_cache")
+      .scriptsCached;
 
 
 var counter = 0;
@@ -332,16 +334,13 @@ var popAndEncryptRemoteScript = function (test) {
     try {
         var currentUrl = list.pop();
         var script = {url: currentUrl};
-        require('html_script_finder/dom_handler/request').request(script, 
-                function (script, data) {
-                    //console.log('"',scriptsCached.getHash(data), '":
-                    //{"filename": "', currentUrl, '", "result": 6}');
-                    counter++;
-                    popAndEncryptRemoteScript(test);
-
-                    
-                }).request();
-        
+        require('../lib/html_script_finder/dom_handler/request').request(
+            script, function (script, data) {
+                //console.log('"',scriptsCached.getHash(data), '":
+                //{"filename": "', currentUrl, '", "result": 6}');
+                counter++;
+                popAndEncryptRemoteScript(test);
+            }).request();
     } catch (e) {
         test.assertEqual(counter, totalScripts);
         test.done();
